#if SLANG_VERSION < 20000 /* {{{ */
#define SLclass_get_class_id(x)	(x)->cl_data_type
#define SLang_get_error()	SLang_Error
#define SLang_set_error(x)	(SLang_Error = (x))
#define SLang_pop_double(x)	SLang_pop_double(x, NULL, NULL)
#define SLang_pop_uint		SLang_pop_uinteger
#define SLang_pop_int		SLang_pop_integer
#define SLang_push_uint		SLang_push_uinteger
#define SLang_push_int		SLang_push_integer
#define SLutf8_enable(x)	x
#define SLang_pop_struct	_SLang_pop_struct
#define SLang_free_struct	_SLstruct_delete_struct
#define SLstack_depth		_SLstack_depth
#define SLuindex_Type		unsigned int
#define SLindex_Type		int
extern LINKAGE int _SLstack_depth(void);
#endif /* }}} */

